<?php
require_once('vendor/autoload.php');

define('BOT_NAME', 'Druplicon');
define('DATABASE_TABLE', 'bot_factoid');

use React\EventLoop\Factory;
use BotMan\BotMan\BotMan;
use BotMan\BotMan\BotManFactory;
use BotMan\BotMan\Drivers\DriverManager;
use BotMan\Drivers\Slack\SlackRTMDriver;

$dotenv = Dotenv\Dotenv::create(__DIR__);
$dotenv->load();

DriverManager::loadDriver(SlackRTMDriver::class);

$slack_api_token = getenv('SLACK_API_TOKEN');
$database_username = getenv('DATABASE_USERNAME');
$database_password = getenv('DATABASE_PASSWORD');

$loop = Factory::create();
/** @var \Botman\Botman\Botman $botman */
$botman = BotManFactory::createForRTM([
  'slack' => [
    'token' => $slack_api_token,
  ],
], $loop);

$host = 'localhost';
$db   = 'druplicon';
$charset = 'utf8mb4';

$dsn = "mysql:host=$host;dbname=$db;charset=$charset";
$options = [
  PDO::ATTR_ERRMODE            => PDO::ERRMODE_EXCEPTION,
  PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
  PDO::ATTR_EMULATE_PREPARES   => false,
];
try {
  global $database_connection;
  $database_connection= new PDO($dsn, $database_username, $database_password, $options);
} catch (\PDOException $e) {
  throw new \PDOException($e->getMessage(), (int)$e->getCode());
}

$botman->hears(BOT_NAME . ':[ ]*{subject_input}[ ]*\?', function ($bot, $whitespace_pattern_1, $subject_input) {
  global $database_connection;
  $table = DATABASE_TABLE;
  $subject = trim($subject_input);
  $bot->reply('subject: ' . $subject . '.');

  $sql = "SELECT statement FROM $table WHERE subject = :subject";
  $statement = $database_connection->prepare($sql);
  $arguments = [
    'subject' => $subject,
  ];
  $statement->execute($arguments);
  $results = $statement->fetchAll();
  foreach ($results as $row) {
    $bot->reply('statement: ' . $row['statement']. '.');
  }
});

$loop->run();
